/* Generated automatically. */
static const char configuration_arguments[] = "/pobj/ti-msp430gcc-3.03.04.00/sources/tools/configure --target=msp430-none-elf --program-prefix=msp430- --enable-languages=c --disable-nls --with-mpc=/usr/local --with-mpfr=/usr/local --with-gmp=/usr/local --disable-lto --without-x --prefix=/usr/local --sysconfdir=/etc --mandir=/usr/local/man --infodir=/usr/local/info --localstatedir=/var --disable-silent-rules --disable-gtk-doc";
static const char thread_model[] = "single";

static const struct {
  const char *name, *value;
} configure_default_options[] = { { NULL, NULL} };
