/* GCC option-handling definitions for the TI MSP430
   Copyright (C) 2014 Free Software Foundation, Inc.

   This file is part of GCC.

   GCC is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published
   by the Free Software Foundation; either version 3, or (at your
   option) any later version.

   GCC is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   You should have received a copy of the GNU General Public License
   along with GCC; see the file COPYING3.  If not see
   <http://www.gnu.org/licenses/>.  */

#ifndef MSP430_OPTS_H
#define MSP430_OPTS_H

enum msp430_hwmult_types
{
  NONE,
  AUTO,
  SMALL,
  LARGE,
  F5SERIES
};

enum msp430_regions
{
  ANY,
  EITHER,
  LOWER,
  UPPER
};
#endif
